@@ -3,7 +3,7 @@
 import os
 import fnmatch
 
-def all_file(root, patterns='*.pyc', ignore_dirs=[], \
+def all_file(root, patterns='*.pyc', ignore_dirs={}, \
         single_level=False, logger=None, no_matchs=False):
     """
     root:            需要遍历的目录
@@ -11,39 +11,39 @@ def all_file(root, patterns='*.pyc', ignore_dirs=[], \
     single_level:    是否只遍历单层目录，默认为否
     """
     patterns = tuple([p.strip() for p in patterns.split(',')])
+    ignore_dir = ''
     for path, subdirs, files in os.walk(root):
-        ig = False
-        for ignore_dir in ignore_dirs:
-            if path.startswith(ignore_dir):
-                ig = True
-                break
-        if ig:
+        if ignore_dir and path.startswith(ignore_dir):
+            log('ignore subdir %s' % path, logger)
+            continue
+        if ignore_dirs.get(os.path.basename(path), None):
+            log('ignore dir %s' % path, logger)
+            ignore_dir = path
             continue
         for pattern in patterns:
             fs = fnmatch.filter(files, pattern)
             if not fs:
-                if logger and no_matchs:
-                    logger.debug('no match files in %s' % path)
-                elif no_matchs:
-                    print 'no match files in %s' % path
+                if no_matchs: log('no match files in %s' % path, logger)
                 continue
             for name in fs:
                 yield os.path.join(path, name)
         if single_level:
             break
 
+def log(msg, logger=None):
+    if logger:
+        logger.debug(msg)
+    else:
+        print msg
+
 def clean(args, logger=None, no_matchs=False):
     filter = args.filter
-    ignore_dirs = []
     if args.ignore_dirs:
-        ignore_dirs = [os.path.join(args.path, d.strip()) for d in args.ignore_dirs.split(',')]
+        ignore_dirs = dict([(d.strip(), 1) for d in args.ignore_dirs.split(',') if d])
     path = args.path
     for f in all_file(path, filter, ignore_dirs, logger=logger, \
             no_matchs=no_matchs):
-        if logger:
-            logger.debug(f)
-        else:
-            print f
+        log(f, logger)
         try:
             os.remove(os.path.realpath(f))
         except Exception, e:
